emgfit API docs
===============

emgfit.ame\_funcs module
------------------------
Module for importing and handling of literature mass values from the Atomic Mass
Evaluation 2016 (AME2016).

.. automodule:: emgfit.ame_funcs
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.config module
--------------------
Configuration file with general settings for emgfit package.

.. automodule:: emgfit.config
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.emg\_funcs module
------------------------
Module with numerically robust implementation of the hyper-exponentially-
modified Gaussian probability density function.

.. automodule:: emgfit.emg_funcs
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.fit\_models module
-------------------------
Module with lmfit models for single peaks with Gaussian or various
hyper-exponentially-modified Gaussian line shapes.

.. automodule:: emgfit.fit_models
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.sample module
-------------------------
Module for creating simulated time-of-flight mass spectra with Gaussian and
hyper-exponentially-modified line shapes.

.. automodule:: emgfit.sample
   :members:
   :undoc-members:
   :show-inheritance:


emgfit.spectrum module
----------------------
Module for fitting time-of-flight mass spectra.

.. automodule:: emgfit.spectrum
   :members:
   :undoc-members:
   :private-members: spectrum._eval_peakshape_errors, spectrum.get_MC_peakshape_errors, spectrum._eval_MC_peakshape_errors, spectrum._get_MCMC_par_samples
   :show-inheritance:
